import type { Metadata } from "next";
import localFont from "next/font/local";
import { notFound } from "next/navigation";

import { getServerSession } from "next-auth";

import { getMessages } from "@/actions/get-messages";
import { Toaster as ToasterSonner } from "@/components/ui/sonner";
import { Toaster } from "@/components/ui/toaster";
import { routing } from "@/i18n/routing";
import SessionAuth from "@/layouts/client-layout/session-provider";
import { authOptions } from "@/lib/auth-options";
import { QueryProvider } from "@/lib/query-provider";
import type { LocaleParams } from "@/types/params";

import "../globals.css";
import IntlClientProvider from "./intl-client-provider";

const droidArabicKufi = localFont({
	src: "../fonts/Droid-Arabic-Kufi.ttf.woff",
	variable: "--font-droid-arabic-kufi",
});

export const metadata: Metadata = {
	title: "A.BIN Taleb",
	description: "Swimming Pools CO",
};

export default async function RootLayout({
	children,
	params,
}: {
	children: React.ReactNode;
	params: LocaleParams;
}) {

	const { locale } = await params;

	if (!routing.locales.includes(locale)) {
		notFound();
	}

	const messages = await getMessages(locale);

	let session = null;
	try {
		session = await getServerSession(authOptions);
	} catch (error) {
		console.log("error", error);
	}

	return (
		<html lang={locale} dir={locale === "ar" ? "rtl" : "ltr"}>
			<body className={`${droidArabicKufi.variable} antialiased`}>
				<IntlClientProvider messages={messages} locale={locale}>
					<SessionAuth session={session ? session : null}>
						<QueryProvider>
							{children}
						</QueryProvider>
					</SessionAuth>
				</IntlClientProvider>
				<ToasterSonner
					style={{
						fontFamily: "var(--font-droid-arabic-kufi)",
					}}
					toastOptions={{
						classNames: {
							error:
								"bg-destructive text-white text-base font-bold p-4 rounded-lg shadow-lg border-none",
							success:
								"bg-[#2895c8] text-white text-base font-bold p-4 rounded-lg shadow-lg border-none",
						},
					}}
				/>
				<Toaster />
			</body>
		</html>
	);
}
